"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const child_process_1 = __importDefault(require("child_process"));
const util_1 = __importDefault(require("util"));
const exec = util_1.default.promisify(child_process_1.default.exec);
const spawn = util_1.default.promisify(child_process_1.default.spawn);
function getUserHome() {
    return process.env[(process.platform == 'win32') ? 'USERPROFILE' : 'HOME'];
}
class VysorBinary {
    vb;
    constructor(vb) {
        this.vb = vb;
    }
    launch(...argv) {
        let launchCommand;
        let launchArgs = [];
        if (process.platform === 'win32') {
            launchCommand = this.vb;
        }
        else if (process.platform === 'darwin') {
            launchCommand = this.vb;
        }
        else if (process.platform === 'linux') {
            launchCommand = 'gtk-launch';
            launchArgs.push(this.vb);
        }
        else {
            throw new Error('unknown platform');
        }
        launchArgs.push('--args', ...argv);
        spawn(launchCommand, launchArgs, {
            detached: true,
        });
    }
}
async function findVysorBinary() {
    let vb;
    if (process.platform === 'win32') {
        vb = path_1.default.join(getUserHome(), 'Local/Vysor/Vysor.exe');
    }
    else if (process.platform === 'darwin') {
        vb = '/Applications/Vysor.app/Contents/MacOS/Vysor';
    }
    else if (process.platform === 'linux') {
        vb = (await exec('which vysorapp')).stdout.trim();
    }
    else {
        throw new Error('unknown platform');
    }
    if (!fs_1.default.existsSync(vb)) {
        console.error(`Vysor binary was not found at ${vb}.`);
        console.error(`Please install it from https://vysor.io/download`);
        process.exit(1);
    }
    return new VysorBinary(vb);
}
async function main() {
    const vb = await findVysorBinary();
    const argv = process.argv.slice();
    for (const arg of argv) {
        if (arg === '-h' || arg === '-?') {
            console.error(`usage: vysor [options]

The following basic options are available:

-h or -?    Show this usage.

-l          Open the list of Vysor devices
-d          View all physical devices
-e          View all emulators
-s [serial] View device with the given [serial] number.

The following advanced options are available:

-i [id]     Some devices have multiple displays. The default behavior is
            to view the default display. This option overrides
            which display will be viewed. More information below:
            DisplayManager.getDisplays: https://bit.ly/3d07Ztl
            Display.getDisplayId: https://bit.ly/3j8cN3A

If no options are specified, Vysor will be launched as normal.
`);
            return;
        }
    }
    vb.launch(...process.argv);
    process.exit();
}
main();
//# sourceMappingURL=cli.js.map